# History
All notable changes to this project will be documented in this file. This project adheres to [Semantic Versioning](http://semver.org/).

## 0.1.0 (2020-04-27)
* First release on PyPI.


## 0.1.1 (2020-04-27)
* Updated license and installaton instructions due to typo.
